==> foundation-2.6.1.tgz: package/SocialDeviantArt/SocialDeviantArt.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialDeviantArt = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M46.347 44.786c2.026-.797 7.307-1.86 11.093-1.328l4.749 9.896 13.052-3.089c.664-.133.996-.996 0-1.893-8.17-6.575-16.24-7.87-32.181-4.383l9.465 19.727-33.044 9.316v5.995c0 .219.089.419.233.562a.791.791 0 00.563.233h59.248a.794.794 0 00.796-.795V56.123l-25.206 6.696s-7.075-14.247-8.768-18.033z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M79.524 19.513H20.276a.775.775 0 00-.437.148.782.782 0 00-.36.648v25.81c1.266-.977 5.98-4.468 10.528-5.917l-3.886-8.967H37.08s2.89 6.276 2.89 6.376c3.985-1.195 23.114-4.284 40.151 3.089l.199.146V20.31a.781.781 0 00-.36-.648.766.766 0 00-.436-.149zM27.185 61.89c2.458-.531 11.823-3.056 11.823-3.056l-6.045-12.421c-1.66.465-8.634 3.653-8.103 14.347 0 0-.133 1.661 2.325 1.13z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.022 14.133H19.978A5.979 5.979 0 0014 20.11v59.78a5.978 5.978 0 005.978 5.977h60.044A5.979 5.979 0 0086 79.89V20.11c0-3.3-2.677-5.977-5.978-5.977zm2.291 64.893a2.792 2.792 0 01-2.789 2.789H20.276a2.793 2.793 0 01-2.79-2.789V20.31a2.793 2.793 0 012.79-2.789h59.248a2.792 2.792 0 012.789 2.789v58.716z"
  }));
});
SocialDeviantArt.displayName = 'SocialDeviantArt';
export const SocialDeviantArtDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialDeviantArt/SocialDeviantArt.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialDeviantArt = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M46.347 44.786c2.026-.797 7.307-1.86 11.093-1.328l4.749 9.896 13.052-3.089c.664-.133.996-.996 0-1.893-8.17-6.575-16.24-7.87-32.181-4.383l9.465 19.727-33.044 9.316v5.995c0 .219.089.419.233.562a.791.791 0 00.563.233h59.248a.794.794 0 00.796-.795V56.123l-25.206 6.696s-7.075-14.247-8.768-18.033z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M79.524 19.513H20.276a.775.775 0 00-.437.148.782.782 0 00-.36.648v25.81c1.266-.977 5.98-4.468 10.528-5.917l-3.886-8.967H37.08s2.89 6.276 2.89 6.376c3.985-1.195 23.114-4.284 40.151 3.089l.199.146V20.31a.781.781 0 00-.36-.648.766.766 0 00-.436-.149zM27.185 61.89c2.458-.531 11.823-3.056 11.823-3.056l-6.045-12.421c-1.66.465-8.634 3.653-8.103 14.347 0 0-.133 1.661 2.325 1.13z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.022 14.133H19.978A5.979 5.979 0 0014 20.11v59.78a5.978 5.978 0 005.978 5.977h60.044A5.979 5.979 0 0086 79.89V20.11c0-3.3-2.677-5.977-5.978-5.977zm2.291 64.893a2.792 2.792 0 01-2.789 2.789H20.276a2.793 2.793 0 01-2.79-2.789V20.31a2.793 2.793 0 012.79-2.789h59.248a2.792 2.792 0 012.789 2.789v58.716z"
  }));
});
SocialDeviantArt.displayName = 'SocialDeviantArt';
export var SocialDeviantArtDimensions = {
  height: 100,
  width: 100
};
